@@ -7,11 +7,11 @@ Posy - a website generator inspired by blosxom
 
 =head1 VERSION
 
-This describes version B<0.80> of Posy.
+This describes version B<0.90> of Posy.
 
 =cut
 
-our $VERSION = '0.80';
+our $VERSION = '0.90';
 
 =head1 SYNOPSIS
 
@@ -44,8 +44,6 @@ This distribution includes a CGI script (posy.cgi) and two command-line
 scripts (posy_static, posy_one) which use the Posy engine to process input
 data files into web-page output.
 
-It also includes a number of plugins.
-
 =head2 Terms
 
 A few terms:
@@ -77,6 +75,13 @@ This defaults to being the same directory as the data_dir.
 The directory where flavour files are kept (see L</flavour>), in a
 hierarchical manner which mirrors that of the data directory.
 
+=item base_dir, base directory
+
+For convenience, one can just set a "base" directory and Posy will
+set the data_dir to being $base_dir/data, the state_dir to being
+$base_dir/state, and the flavour_dir to being $base_dir/flavours
+and the config_dir to being the same as data_dir.
+
 =item full path, full filename
 
 The absolute location of a given file; the absolute pathname.
@@ -147,7 +152,135 @@ of the output pages while keeping the content separate.
 
 =back
 
-=cut
+=head1 REQUIRES
+
+    File::Spec
+    File::stat
+
+    File::Find
+    Data::Dumper
+    Storable
+    CGI::Minimal
+
+    Test::More
+
+=head1 INSTALLATION
+
+Since this is a set of modules and scripts for a website-generator, then
+installation needs will vary depending on the particular setup a person
+has.  There are two parts to the installation, no matter the setup:
+installing the modules, and installing the CGI script.
+
+This section covers installing the modules.  The instructions for
+installing the CGI script are in the script itself; just run perldoc on it.
+
+    perldoc ./posy.cgi
+
+But first, the modules.
+
+=head2 Administrator, Automatic
+
+If you are the administrator of the system, then the dead simple method of
+installing the modules is to use the CPAN or CPANPLUS system.
+
+    cpanp -i Posy
+
+This will install the modules and the B<posy_static> and B<posy_one>
+scripts in the usual places which they get installed when one is using
+CPAN(PLUS).
+
+Note, however, that this does NOT install the CGI script, and that this
+will need to be done separately.  Therefore you will need to grovel around
+to find the directory into which the Posy source was placed, in order to
+get at the CGI script to install it.  Therefore you may find it simpler
+to just download the Posy tarball and install it by hand.
+
+Or, you may wish to install the Posy bundle:
+
+    cpanp -i Bundle-Posy
+
+This installs not only the base Posy system, but all the major plugins.
+You still have to install the posy.cgi by hand, though.
+
+=head2 Administrator, By Hand
+
+If you are the administrator of the system, but don't wish to use the
+CPAN(PLUS) method, then this is for you.  Take the Posy-*.tar.gz file
+and untar it in a suitable directory.
+
+    tar -xzvf Posy-0.81.tar.gz
+    cd Posy-0.81
+
+To install this module, run the following commands:
+
+    perl Build.PL
+    ./Build
+    ./Build test
+    ./Build install
+
+Or, if you're on a platform (like DOS or Windows) that doesn't like the
+"./" notation, you can do this:
+
+   perl Build.PL
+   perl Build
+   perl Build test
+   perl Build install
+
+=head2 User With Shell Access
+
+If you are a user on a system, and don't have root/administrator access,
+you need to install Posy somewhere other than the default place (since you
+don't have access to it).  However, if you have shell access to the system,
+then you can install it in your home directory.
+
+Say your home directory is "/home/fred", and you want to install the
+modules into a subdirectory called "perl".
+
+Download the Posy-*tar.gz file.
+
+    tar -xzvf Posy-0.81.tar.gz
+    cd Posy-0.81
+    perl Build.PL --install_base /home/fred/perl
+    ./Build
+    ./Build test
+    ./Build install
+
+This will install the files underneath /home/fred/perl.
+
+You will then need to make sure that you alter the PERL5LIB variable to
+find the modules, and the PATH variable to find the scripts (posy_one,
+posy_static).
+
+Therefore you will need to change:
+your path, to include /home/fred/perl/script (where the script will be)
+
+	PATH=/home/fred/perl/script:${PATH}
+
+the PERL5LIB variable to add /home/fred/perl/lib
+
+	PERL5LIB=/home/fred/perl/lib:${PERL5LIB}
+
+If you alter these in your setup files (e.g. .login) then they will be
+set when you log in, and you will be able to run the scripts without
+having to do anything special.
+
+However, please take note of the value you used for PERL5LIB -- you will
+need this when setting up the CGI script.
+
+=head2 User With FTP-only Access
+
+Okay, so you have an ISP/Web-Host, where you have your site, and you want
+to use Posy for it.  You can ftp files from your PC to your site, but you
+don't have shell access.  The most sensible thing I can think of is that
+you set up your entire site on your own PC at home, and then mirror it with
+FTP on your account with your ISP.  If your ISP uses Linux, then it would
+probably be easier on you if you got Linux as well. (But how to install
+Linux is definitely beyond the scope of this document!)
+
+So follow the instructions for L</User With Shell Access>, but I can't
+guarantee that it will work, since if you don't have shell access on the
+system which has your web pages, it will be harder to troubleshoot if
+things go wrong.
 
 =head1 CLASS METHODS
 
@@ -195,58 +328,6 @@ sub import {
     }
 } # import
 
-=head1 REQUIRES
-
-    File::Spec
-    File::stat
-
-    File::Find
-    Data::Dumper
-    Storable
-    CGI::Minimal
-
-    Test::More
-
-=head1 INSTALLATION
-
-To install this module, run the following commands:
-
-    perl Build.PL
-    ./Build
-    ./Build test
-    ./Build install
-
-Or, if you're on a platform (like DOS or Windows) that doesn't like the
-"./" notation, you can do this:
-
-   perl Build.PL
-   perl Build
-   perl Build test
-   perl Build install
-
-In order to install somewhere other than the default, such as
-in a directory under your home directory, like "/home/fred/perl"
-go
-
-   perl Build.PL --install_base /home/fred/perl
-
-as the first step instead.
-
-This will install the files underneath /home/fred/perl.
-
-You will then need to make sure that you alter the PERL5LIB variable to
-find the modules, and the PATH variable to find the script.
-
-Therefore you will need to change:
-your path, to include /home/fred/perl/script (where the script will be)
-
-	PATH=/home/fred/perl/script:${PATH}
-
-the PERL5LIB variable to add /home/fred/perl/lib
-
-	PERL5LIB=/home/fred/perl/lib:${PERL5LIB}
-
-
 =head1 SEE ALSO
 
 perl(1).
